'use strict';

var index = require('../index.cjs');
var session = require('../session-bc462427.cjs');
var alias = require('../alias-aa343af5.cjs');
require('mysql2/promise');

class MySqlRemoteSession extends session.MySqlSession {
    client;
    schema;
    static [alias.entityKind] = 'MySqlRemoteSession';
    logger;
    constructor(client, dialect, schema, options) {
        super(dialect);
        this.client = client;
        this.schema = schema;
        this.logger = options.logger ?? new index.NoopLogger();
    }
    prepareQuery(query, fields, customResultMapper) {
        return new PreparedQuery(this.client, query.sql, query.params, this.logger, fields, customResultMapper);
    }
    all(query) {
        const querySql = this.dialect.sqlToQuery(query);
        this.logger.logQuery(querySql.sql, querySql.params);
        return this.client(querySql.sql, querySql.params, 'all').then(({ rows }) => rows);
    }
    async transaction(_transaction, _config) {
        throw new Error('Transactions are not supported by the MySql Proxy driver');
    }
}
class MySqlProxyTransaction extends session.MySqlTransaction {
    static [alias.entityKind] = 'MySqlProxyTransaction';
    async transaction(_transaction) {
        throw new Error('Transactions are not supported by the MySql Proxy driver');
    }
}
class PreparedQuery extends session.PreparedQuery {
    client;
    queryString;
    params;
    logger;
    fields;
    customResultMapper;
    static [alias.entityKind] = 'MySqlProxyPreparedQuery';
    constructor(client, queryString, params, logger, fields, customResultMapper) {
        super();
        this.client = client;
        this.queryString = queryString;
        this.params = params;
        this.logger = logger;
        this.fields = fields;
        this.customResultMapper = customResultMapper;
    }
    async execute(placeholderValues = {}) {
        const params = alias.fillPlaceholders(this.params, placeholderValues);
        const { fields, client, queryString, logger, joinsNotNullableMap, customResultMapper } = this;
        logger.logQuery(queryString, params);
        if (!fields && !customResultMapper) {
            const { rows } = await client(queryString, params, 'execute');
            return rows;
        }
        const { rows } = await client(queryString, params, 'all');
        if (customResultMapper) {
            return customResultMapper(rows);
        }
        return rows.map((row) => alias.mapResultRow(fields, row, joinsNotNullableMap));
    }
    iterator(_placeholderValues = {}) {
        throw new Error('Streaming is not supported by the MySql Proxy driver');
    }
}

function drizzle(callback, config = {}) {
    const dialect = new session.MySqlDialect();
    let logger;
    if (config.logger === true) {
        logger = new index.DefaultLogger();
    }
    else if (config.logger !== false) {
        logger = config.logger;
    }
    let schema;
    if (config.schema) {
        const tablesConfig = alias.extractTablesRelationalConfig(config.schema, alias.createTableRelationsHelpers);
        schema = {
            fullSchema: config.schema,
            schema: tablesConfig.tables,
            tableNamesMap: tablesConfig.tableNamesMap,
        };
    }
    const session$1 = new MySqlRemoteSession(callback, dialect, schema, { logger });
    return new session.MySqlDatabase(dialect, session$1, schema, 'default');
}

exports.MySqlProxyTransaction = MySqlProxyTransaction;
exports.MySqlRemoteSession = MySqlRemoteSession;
exports.PreparedQuery = PreparedQuery;
exports.drizzle = drizzle;
//# sourceMappingURL=index.cjs.map
