'use strict';

var migrator = require('../migrator.cjs');
var alias = require('../alias-aa343af5.cjs');
require('node:crypto');
require('node:fs');
require('node:path');

async function migrate(db, callback, config) {
    const migrations = migrator.readMigrationFiles(config);
    const migrationsTable = config.migrationsTable ?? '__drizzle_migrations';
    const migrationTableCreate = alias.sql `
		create table if not exists ${alias.sql.identifier(migrationsTable)} (
			id serial primary key,
			hash text not null,
			created_at bigint
		)
	`;
    await db.execute(migrationTableCreate);
    const dbMigrations = await db.select({
        id: alias.sql.raw('id'),
        hash: alias.sql.raw('hash'),
        created_at: alias.sql.raw('created_at'),
    }).from(alias.sql.raw(migrationsTable)).orderBy(alias.sql.raw('created_at desc')).limit(1);
    const lastDbMigration = dbMigrations[0];
    const queriesToRun = [];
    for (const migration of migrations) {
        if (!lastDbMigration
            || Number(lastDbMigration.created_at) < migration.folderMillis) {
            queriesToRun.push(...migration.sql, `insert into ${alias.sql.identifier(migrationsTable)} (\`hash\`, \`created_at\`) values(${migration.hash}, ${migration.folderMillis})`);
        }
    }
    await callback(queriesToRun);
}

exports.migrate = migrate;
//# sourceMappingURL=migrator.cjs.map
